@@ -96,6 +96,7 @@ gpg_err_init (void)
           /* No way to continue - commit suicide.  */
           abort ();
         }
+      _gpg_w32__init_gettext_module ();
       real_init ();
     }
 # endif /*!DLL_EXPORT*/
@@ -234,6 +235,27 @@ get_locale_dir (void)
               p = strrchr (result, '\\');
               if (p)
                 *p = 0;
+              /* If we are installed below "bin" strip that part and
+                 use the top directory instead.
+
+                 Background: Under Windows we don't install GnuPG
+                 below bin/ but in the top directory with only share/,
+                 lib/, and etc/ below it.  One of the reasons is to
+                 keep the the length of the filenames at bay so not to
+                 increase the limited length of the PATH envvar.
+                 Another and more important reason, however, is that
+                 the very first GPG versions on W32 were installed
+                 into a flat directory structure and for best
+                 compatibility with these versions we didn't changed
+                 that later.  For WindowsCE we can right away install
+                 it under bin, though.  The hack with detection of the
+                 bin directory part allows us to eventually migrate to
+                 such a directory layout under plain Windows without
+                 the need to change libgpg-error.  */
+              p = strrchr (result, '\\');
+              if (p && !strcmp (p+1, "bin"))
+                *p = 0;
+              /* Append the static part.  */
               strcat (result, SLDIR);
             }
         }
@@ -308,6 +330,10 @@ _gpg_w32ce_strerror (int err)
 
   if (err == -1)
     err = _gpg_w32ce_get_errno ();
+
+  /* Note: On a German HTC Touch Pro2 device I also tried
+     LOCALE_USER_DEFAULT and LOCALE_SYSTEM_DEFAULT - both returned
+     English messages.  */
   if (FormatMessageW (FORMAT_MESSAGE_FROM_SYSTEM, NULL, err,
                       MAKELANGID (LANG_NEUTRAL, SUBLANG_DEFAULT),
                       tmpbuf, STRBUFFER_SIZE -1,
