@@ -1,6 +1,6 @@
 /* w32-gettext.h - A simple gettext implementation for Windows targets.
    Copyright (C) 1995, 1996, 1997, 1999, 2005, 2007,
-2                 2008, 2010 Free Software Foundation, Inc.
+                 2008, 2010 Free Software Foundation, Inc.
 
    This file is part of libgpg-error.
  
@@ -1146,14 +1146,33 @@ static char *current_domainname;
 
 
 
-/* Constructor for this module.  Called from DllMain.  */
+/* Constructor for this module.  This can only be used if we are a
+   DLL.  IF used as a static lib we can't control the process set; for
+   example it might be used with a main module which is not build with
+   mingw and thus does not know how to call the constructors.  */
+#ifdef DLL_EXPORT
 static void module_init (void) __attribute__ ((__constructor__));
+#endif
 static void
 module_init (void)
 {
-  InitializeCriticalSection (&domainlist_access_cs);
+  static int init_done;
+
+  if (!init_done)
+    {
+      InitializeCriticalSection (&domainlist_access_cs);
+      init_done = 1;
+    }
 }
 
+#ifndef DLL_EXPORT
+void
+_gpg_w32__init_gettext_module (void)
+{
+  module_init ();
+}
+#endif
+
 
 /* Free the domain data.  */
 static void
